"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setPackageName = setPackageName;
exports.setIndexTsAndServiceCode = setIndexTsAndServiceCode;
exports.getFileLocation = getFileLocation;
exports.setFileLocation = setFileLocation;
exports.getLatestNPMVersions = getLatestNPMVersions;
exports.getCodegenLocation = getCodegenLocation;
exports.installNpm = installNpm;
exports.fixUsingLint = fixUsingLint;
exports.generateCode = generateCode;
exports.copyBasicConfigFiles = copyBasicConfigFiles;
exports.removeNodeModules = removeNodeModules;
exports.renameJs2Ts = renameJs2Ts;
exports.processCodes = processCodes;
exports.generateDefaultTest = generateDefaultTest;
exports.copyWriterTs = copyWriterTs;
exports.fixVariousCodeSegment = fixVariousCodeSegment;
exports.updatingGatewayJson = updatingGatewayJson;
exports.asyncUpdatingLatestVersionOfNpms = asyncUpdatingLatestVersionOfNpms;
const YAML = __importStar(require("yaml"));
const fs = __importStar(require("fs"));
const shelljs_1 = __importDefault(require("shelljs"));
const lodash_1 = require("lodash");
const log4js = __importStar(require("log4js"));
const package_json_1 = __importDefault(require("package-json"));
const data_js_1 = require("./data.js");
const logger = log4js.getLogger();
logger.level = 'DEBUG';
const { exec, cp, rm, find, mv, env, sed, cd, mkdir, cat, } = shelljs_1.default;
let fileLocation = null;
function setPackageName(fileName, destination) {
    const nameList = fileName.split('/');
    const lastNameList = nameList[nameList.length - 1].split('.');
    const lastName = lastNameList[0];
    const elementList = lastName.split('-');
    const domain = elementList[1];
    let appTemp = '';
    // eslint-disable-next-line no-plusplus
    for (let i = 3; i < elementList.length; i++) {
        appTemp += `${elementList[i]}-`;
    }
    const app = appTemp.slice(0, -1);
    const list = fs.readdirSync(`${destination}/service`);
    let targetFileName;
    list.forEach((filename) => {
        if (filename !== 'HealthCheckService.ts') {
            targetFileName = filename.split('.');
        }
    });
    const serviceName = `${targetFileName[0]}.ts`;
    console.log(`destination: ${destination}, serviceName: ${serviceName}, lastName: ${lastName}, domain: ${domain}, app: ${app}`);
    sed('-i', 'REPLACE_WITH_NAME', lastName, `${destination}/package.json`);
    sed('-i', 'REPLACE_WITH_DOMAIN', domain, `${destination}/service/${serviceName}`);
    sed('-i', 'REPLACE_WITH_AP', app, `${destination}/service/${serviceName}`);
}
function setIndexTsAndServiceCode(destination) {
    const list = fs.readdirSync(`${destination}/service`);
    let targetFileName;
    list.forEach((filename) => {
        if (filename !== 'HealthCheckService.ts') {
            targetFileName = filename.split('.');
        }
    });
    const serviceName = `${targetFileName[0]}.ts`;
    sed('-i', 'REPLACE_WITH_SERVICE', targetFileName[0], `${destination}/index.ts`);
    cat(`${fileLocation}/codegen/files/head-of-service`).cat(`${destination}/service/${serviceName}`).to(`${destination}/service/${serviceName}`);
}
function getFileLocation() {
    return fileLocation;
}
function setFileLocation(data) {
    fileLocation = data;
}
async function getLatestNPMVersions(packageJSON) {
    const myPackageJSON = (0, lodash_1.cloneDeep)(packageJSON);
    try {
        const keyList = Object.keys(myPackageJSON.dependencies);
        const result = [];
        keyList.forEach((element) => {
            result.push((0, package_json_1.default)(element));
        });
        const myResult = await Promise.all(result);
        myPackageJSON.dependencies = {};
        myResult.forEach((element) => {
            myPackageJSON.dependencies[element.name] = `^${element.version}`;
        });
        const keyListDev = Object.keys(myPackageJSON.devDependencies);
        const resultDev = [];
        keyListDev.forEach((element) => {
            resultDev.push((0, package_json_1.default)(element));
        });
        const myResultDev = await Promise.all(resultDev);
        myPackageJSON.devDependencies = {};
        myResultDev.forEach((element) => {
            // if (element.name === 'jest') {
            //   myPackageJSON.devDependencies[element.name] = '28.1.3';
            // } else {
            myPackageJSON.devDependencies[element.name] = `^${element.version}`;
            // }
        });
        return myPackageJSON;
    }
    catch (ex) {
        return ex;
    }
}
function getCodegenLocation() {
    return env.CODEGEN;
}
function installNpm(destination) {
    cd(destination);
    exec('npm install');
}
function fixUsingLint(destination) {
    cd(destination);
    exec('npx eslint --fix service/* > /dev/null');
}
function generateCode(fileName, destination) {
    if (exec(`java -jar ${fileLocation}/codegen/swagger-codegen-cli.jar generate -i ${fileName} -l nodejs-server -o ${destination}`).code !== 0) {
        logger.error('Codegen error');
        process.exit(-1);
    }
}
function copyBasicConfigFiles(destination) {
    const sourcePath = `${fileLocation}/codegen/files`;
    console.log(`Copying config files from ${sourcePath} to ${destination}`);
    data_js_1.configFiles.forEach((element) => {
        if (element === 'gitignore') {
            if (cp(`${sourcePath}/${element}`, `${destination}/.gitignore`).code !== 0) {
                logger.error(`Copy error of ${element}`);
                process.exit(-1);
            }
        }
        else if (cp(`${sourcePath}/${element}`, destination).code !== 0) {
            logger.error(`Copy error of ${element}`);
            process.exit(-1);
        }
        else {
            logger.info(`Copied ${element} to ${destination}`);
        }
    });
}
function removeNodeModules(destination) {
    rm('-rf', `${destination}/node_modules`);
}
function renameJs2Ts(destination) {
    const fileList = find(destination).filter((file) => file.match(/\.js$/));
    fileList.forEach((element) => {
        mv(element, element.replace(/.js$/, '.ts'));
    });
}
function processCodes(destination) {
    const fileList = find(destination).filter((file) => file.match(/\.ts$/));
    fileList.forEach((element) => {
        sed('-i', '= function', '', element);
        sed('-i', 'exports.', 'export async function ', element);
        sed('-i', '\'use strict\';', '', element);
        sed('-i', '(\\s+([a-zA-Z]+\\s+)+)Promise\\(function\\(resolve, reject\\) \\{', '', element);
        sed('-i', '  \\}\\);', '', element);
        sed('-i', 'resolve\\(', 'return(', element);
        sed('-i', 'return\\(\\)', 'return null', element);
        sed('-i', '  var examples = \\{\\};', '', element);
        sed('-i', 'examples\\[\'application/json\']', 'const examples', element);
        sed('-i', '\\(examples\\[Object\\.keys\\(examples\\)\\[0]]\\)', ' examples', element);
    });
}
function generateDefaultTest(destination) {
    mkdir(`${destination}/__tests__`);
    const src = `${fileLocation}/codegen/files/__tests__/Default.test.ts`;
    const dest = `${destination}/__tests__/Default.test.ts`;
    cp(src, dest);
}
function copyWriterTs(destination) {
    const src = `${fileLocation}/codegen/files/utils/writer.ts`;
    const dest = `${destination}/utils/writer.ts`;
    cp(src, dest);
}
function fixVariousCodeSegment(destination) {
    data_js_1.sedFiles.forEach((element) => {
        if (element.command.type === 'sed') {
            sed(element.command.params[0], element.command.params[1], element.command.params[2], `${destination}/${element.file}`);
        }
    });
    const fileList2 = find(`${destination}/service`).filter((file) => file.match(/\.ts$/));
    fileList2.forEach((element) => {
        sed('-i', ' resolve();', ' resolve(null);', element);
    });
}
function updatingGatewayJson(destination) {
    const file = fs.readFileSync(`${destination}/api/openapi.yaml`, 'utf8');
    const result = YAML.parse(file);
    const pathList = [];
    const methodList = [];
    Object.keys(result.paths).forEach((element) => {
        if (element !== '/health-check') {
            pathList.push(element);
            Object.keys(result.paths[element]).forEach((subElement) => {
                if (!methodList.includes(subElement)) {
                    methodList.push(subElement.toUpperCase());
                }
            });
        }
    });
    const outputData = {
        type: 'external',
        paths: pathList,
        methods: methodList,
        regex_priority: 2,
    };
    const outString = JSON.stringify(outputData, null, 2);
    fs.writeFileSync(`${destination}/gateway.json`, outString);
}
async function asyncUpdatingLatestVersionOfNpms(destination) {
    const targetData = fs.readFileSync(`${destination}/package.json`, 'utf8');
    const targetJson = JSON.parse(targetData);
    const solvedTargetJSON = await getLatestNPMVersions(targetJson);
    const targetFileContent = JSON.stringify(solvedTargetJSON, null, 2);
    fs.writeFileSync(`${destination}/package.json`, targetFileContent);
}
//# sourceMappingURL=tools.js.map